PeripheralInput

Trait PeripheralInput 

pub trait PeripheralInput<'d>: Into<InputSignal<'d>> + PeripheralSignal<'d> { }
A signal that can be connected to a peripheral input.

Peripheral drivers are encouraged to accept types that implement this and PeripheralOutput as arguments instead of pin types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl PeripheralInput<'_> for Level

Available on crate feature unstable only.
Source

impl PeripheralInput<'_> for NoPin

Available on crate feature unstable only.
Source

impl<'d> PeripheralInput<'d> for AnyPin<'d>

Source

impl<'d> PeripheralInput<'d> for Flex<'d>

Available on crate feature unstable only.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> PeripheralInput<'d> for GPIO0<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO1<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO2<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO3<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO4<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO5<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO6<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO7<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO8<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO9<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO10<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO11<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO12<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO13<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO14<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO15<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO16<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO17<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO18<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO19<'d>

Source

impl<'d> PeripheralInput<'d> for GPIO20<'d>

Source

impl<'d> PeripheralInput<'d> for Input<'d>

Available on crate feature unstable only.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> PeripheralInput<'d> for InputSignal<'d>

Available on crate feature unstable only.