pub trait PeripheralSignal<'d>: Sealed { }Expand description
The base of all peripheral signals.
This trait represents a signal in the GPIO matrix. Signals are converted or split from GPIO pins and can be connected to peripheral inputs and outputs.
All signals can be peripheral inputs, but not all output-like types should be allowed to be passed as inputs. This trait bridges this gap by defining the logic, but not declaring the signal to be an actual Input signal.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl PeripheralSignal<'_> for Level
unstable only.impl PeripheralSignal<'_> for NoPin
unstable only.impl<'d> PeripheralSignal<'d> for AnyPin<'d>
impl<'d> PeripheralSignal<'d> for Flex<'d>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl<'d> PeripheralSignal<'d> for GPIO0<'d>
impl<'d> PeripheralSignal<'d> for GPIO1<'d>
impl<'d> PeripheralSignal<'d> for GPIO2<'d>
impl<'d> PeripheralSignal<'d> for GPIO3<'d>
impl<'d> PeripheralSignal<'d> for GPIO4<'d>
impl<'d> PeripheralSignal<'d> for GPIO5<'d>
impl<'d> PeripheralSignal<'d> for GPIO6<'d>
impl<'d> PeripheralSignal<'d> for GPIO7<'d>
impl<'d> PeripheralSignal<'d> for GPIO8<'d>
impl<'d> PeripheralSignal<'d> for GPIO9<'d>
impl<'d> PeripheralSignal<'d> for GPIO10<'d>
impl<'d> PeripheralSignal<'d> for GPIO11<'d>
impl<'d> PeripheralSignal<'d> for GPIO12<'d>
impl<'d> PeripheralSignal<'d> for GPIO13<'d>
impl<'d> PeripheralSignal<'d> for GPIO14<'d>
impl<'d> PeripheralSignal<'d> for GPIO15<'d>
impl<'d> PeripheralSignal<'d> for GPIO16<'d>
impl<'d> PeripheralSignal<'d> for GPIO17<'d>
impl<'d> PeripheralSignal<'d> for GPIO18<'d>
impl<'d> PeripheralSignal<'d> for GPIO19<'d>
impl<'d> PeripheralSignal<'d> for GPIO20<'d>
impl<'d> PeripheralSignal<'d> for Input<'d>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl<'d> PeripheralSignal<'d> for InputSignal<'d>
unstable only.impl<'d> PeripheralSignal<'d> for Output<'d>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl<'d> PeripheralSignal<'d> for OutputSignal<'d>
unstable only.